#define TCPIPV4
#define MAXSOCKETS 10000

#include <sys/types.h>
#include <sys/socket.h>
#include <sys/un.h>

// Protocol definition for communication between RROS2D and client interfaces

typedef struct _RROS2_MESSAGE
{
	int		Request;			// RequestID
	int		Response;			// Response from RROS2
	int		Sequence;			// RROS2 will return this number as sent. Client should use unique #'s
	int		Position;			// current read/write position in bufferspace (index)
	int		Space;				// Num bytes of payload space used/available
	char	Payload[1024];		// Bufferspace for payload
} RROS2_MESSAGE;

#define RROS2_HEADER_SIZE	5*sizeof(int)

// Request IDs
#define	RROS2_DETECT_AUTH		1
#define RROS2_SET_AUTH			2
#define	RROS2_LOGIN_STATE		3
#define RROS2_GET_AUTH			4

#define RROS2_LOGIN				10
#define RROS2_LOGOUT			11

#define RROS2_LIST_VARS			20
#define RROS2_SET_VAR			21
#define RROS2_GET_VAR			22

#define RROS2_GET_ERROR			30
#define RROS2_SHUTDOWN			31
#define RROS2_DEBUG				32

// Response IDs
#define RROS2_OK				1
#define RROS2_WARNING			2
#define RROS2_ERROR				3
#define RROS2_FAILED			4
#define RROS2_UNKNOWN_REQUEST	5

// Auth Types
#define RROS2_TOSHIBA			1
#define RROS2_HP				2
#define RROS2_DIGITAL			3

RROS2_MESSAGE	*RROS2_NewMessage();
RROS2_MESSAGE	*RROS2_Transcieve(int, RROS2_MESSAGE *);
int				RROS2_AddString(RROS2_MESSAGE *, char *);
int				RROS2_AddInt(RROS2_MESSAGE *, int);
int				RROS2_GetString(RROS2_MESSAGE *, char **);
int				RROS2_GetInt(RROS2_MESSAGE *, int *);